# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/k8s/v1/node.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/k8s/v1/node.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eyandex/cloud/k8s/v1/node.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe2\x05\n\x04Node\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .yandex.cloud.k8s.v1.Node.Status\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.yandex.cloud.k8s.v1.Node.Spec\x12;\n\x0c\x63loud_status\x18\x03 \x01(\x0b\x32%.yandex.cloud.k8s.v1.Node.CloudStatus\x12\x45\n\x11kubernetes_status\x18\x04 \x01(\x0b\x32*.yandex.cloud.k8s.v1.Node.KubernetesStatus\x1a\xbd\x01\n\x10KubernetesStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\nconditions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.Condition\x12*\n\x06taints\x18\x03 \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12=\n\x10\x61ttached_volumes\x18\x04 \x03(\x0b\x32#.yandex.cloud.k8s.v1.AttachedVolume\x1a\x41\n\x0b\x43loudStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0estatus_message\x18\x03 \x01(\t\x1aj\n\x04Spec\x12\x35\n\tresources\x18\x01 \x01(\x0b\x32\".yandex.cloud.k8s.v1.ResourcesSpec\x12+\n\x04\x64isk\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.k8s.v1.DiskSpec\"\x86\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x11\n\rNOT_CONNECTED\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\t\n\x05READY\x10\x04\x12\x0b\n\x07MISSING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0b\n\x07UNKNOWN\x10\x07\"\xad\x01\n\tCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x37\n\x13last_heartbeat_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14last_transition_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb1\x01\n\x05Taint\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x31\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\x0e\x32!.yandex.cloud.k8s.v1.Taint.Effect\"Y\n\x06\x45\x66\x66\x65\x63t\x12\x16\n\x12\x45\x46\x46\x45\x43T_UNSPECIFIED\x10\x00\x12\x0f\n\x0bNO_SCHEDULE\x10\x01\x12\x16\n\x12PREFER_NO_SCHEDULE\x10\x02\x12\x0e\n\nNO_EXECUTE\x10\x03\"<\n\x0e\x41ttachedVolume\x12\x13\n\x0b\x64river_name\x18\x01 \x01(\t\x12\x15\n\rvolume_handle\x18\x02 \x01(\t\"\xdd\x0b\n\x0cNodeTemplate\x12\x17\n\x04name\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=128\x12p\n\x06labels\x18\x0f \x03(\x0b\x32-.yandex.cloud.k8s.v1.NodeTemplate.LabelsEntryB1\x82\xc8\x31\x04<=32\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x13\n\x0bplatform_id\x18\x01 \x01(\t\x12:\n\x0eresources_spec\x18\x02 \x01(\x0b\x32\".yandex.cloud.k8s.v1.ResourcesSpec\x12\x35\n\x0e\x62oot_disk_spec\x18\x03 \x01(\x0b\x32\x1d.yandex.cloud.k8s.v1.DiskSpec\x12s\n\x08metadata\x18\x04 \x03(\x0b\x32/.yandex.cloud.k8s.v1.NodeTemplate.MetadataEntryB0\x82\xc8\x31\x04<=64\x8a\xc8\x31\x08<=131072\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x0fv4_address_spec\x18\x05 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpecB\x02\x18\x01\x12@\n\x11scheduling_policy\x18\x06 \x01(\x0b\x32%.yandex.cloud.k8s.v1.SchedulingPolicy\x12J\n\x17network_interface_specs\x18\x07 \x03(\x0b\x32).yandex.cloud.k8s.v1.NetworkInterfaceSpec\x12>\n\x10placement_policy\x18\n \x01(\x0b\x32$.yandex.cloud.k8s.v1.PlacementPolicy\x12K\n\x10network_settings\x18\x0b \x01(\x0b\x32\x31.yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings\x12^\n\x1a\x63ontainer_runtime_settings\x18\x0c \x01(\x0b\x32:.yandex.cloud.k8s.v1.NodeTemplate.ContainerRuntimeSettings\x12^\n\x1a\x63ontainer_network_settings\x18\x10 \x01(\x0b\x32:.yandex.cloud.k8s.v1.NodeTemplate.ContainerNetworkSettings\x12\x36\n\x0cgpu_settings\x18\x12 \x01(\x0b\x32 .yandex.cloud.k8s.v1.GpuSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa3\x01\n\x0fNetworkSettings\x12J\n\x04type\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.k8s.v1.NodeTemplate.NetworkSettings.TypeB\x04\xe8\xc7\x31\x01\"D\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\x1a\xa9\x01\n\x18\x43ontainerRuntimeSettings\x12S\n\x04type\x18\x01 \x01(\x0e\x32?.yandex.cloud.k8s.v1.NodeTemplate.ContainerRuntimeSettings.TypeB\x04\xe8\xc7\x31\x01\"8\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44OCKER\x10\x01\x12\x0e\n\nCONTAINERD\x10\x02\x1a+\n\x18\x43ontainerNetworkSettings\x12\x0f\n\x07pod_mtu\x18\x01 \x01(\x03J\x04\x08\x0e\x10\x0fJ\x04\x08\x11\x10\x12J\x04\x08\x08\x10\n\"\xc3\x01\n\x0bGpuSettings\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\x12H\n\x0fgpu_environment\x18\x02 \x01(\x0e\x32/.yandex.cloud.k8s.v1.GpuSettings.GpuEnvironment\"R\n\x0eGpuEnvironment\x12\x1f\n\x1bGPU_ENVIRONMENT_UNSPECIFIED\x10\x00\x12\x15\n\x11RUNC_DRIVERS_CUDA\x10\x01\x12\x08\n\x04RUNC\x10\x02\"\xd4\x01\n\x14NetworkInterfaceSpec\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12\x45\n\x17primary_v4_address_spec\x18\x03 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpec\x12\x45\n\x17primary_v6_address_spec\x18\x04 \x01(\x0b\x32$.yandex.cloud.k8s.v1.NodeAddressSpec\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\"\x92\x01\n\x0fNodeAddressSpec\x12\x41\n\x13one_to_one_nat_spec\x18\x01 \x01(\x0b\x32$.yandex.cloud.k8s.v1.OneToOneNatSpec\x12<\n\x10\x64ns_record_specs\x18\x02 \x03(\x0b\x32\".yandex.cloud.k8s.v1.DnsRecordSpec\"_\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"E\n\x0fOneToOneNatSpec\x12\x32\n\nip_version\x18\x01 \x01(\x0e\x32\x1e.yandex.cloud.k8s.v1.IpVersion\"y\n\rResourcesSpec\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x15\n\x04gpus\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"\x92\x01\n\x08\x44iskSpec\x12^\n\x0c\x64isk_type_id\x18\x01 \x01(\tBH\xf2\xc7\x31\x44|network-ssd|network-hdd|network-ssd-nonreplicated|network-ssd-io-m3\x12&\n\tdisk_size\x18\x02 \x01(\x03\x42\x13\xfa\xc7\x31\x0f\x30-4398046511104\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"-\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.node_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _globals['_NODETEMPLATE_LABELSENTRY']._loaded_options = None
  _globals['_NODETEMPLATE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_NODETEMPLATE_METADATAENTRY']._loaded_options = None
  _globals['_NODETEMPLATE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NODETEMPLATE_NETWORKSETTINGS'].fields_by_name['type']._loaded_options = None
  _globals['_NODETEMPLATE_NETWORKSETTINGS'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS'].fields_by_name['type']._loaded_options = None
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_NODETEMPLATE'].fields_by_name['name']._loaded_options = None
  _globals['_NODETEMPLATE'].fields_by_name['name']._serialized_options = b'\212\3101\005<=128'
  _globals['_NODETEMPLATE'].fields_by_name['labels']._loaded_options = None
  _globals['_NODETEMPLATE'].fields_by_name['labels']._serialized_options = b'\202\3101\004<=32\212\3101\005<=128\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_NODETEMPLATE'].fields_by_name['metadata']._loaded_options = None
  _globals['_NODETEMPLATE'].fields_by_name['metadata']._serialized_options = b'\202\3101\004<=64\212\3101\010<=131072\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_NODETEMPLATE'].fields_by_name['v4_address_spec']._loaded_options = None
  _globals['_NODETEMPLATE'].fields_by_name['v4_address_spec']._serialized_options = b'\030\001'
  _globals['_DNSRECORDSPEC'].fields_by_name['fqdn']._loaded_options = None
  _globals['_DNSRECORDSPEC'].fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _globals['_DNSRECORDSPEC'].fields_by_name['ttl']._loaded_options = None
  _globals['_DNSRECORDSPEC'].fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._serialized_options = b'\372\3071\003>=0'
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._serialized_options = b'\372\3071\003>=0'
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCESSPEC'].fields_by_name['gpus']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['gpus']._serialized_options = b'\372\3071\003>=0'
  _globals['_DISKSPEC'].fields_by_name['disk_type_id']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['disk_type_id']._serialized_options = b'\362\3071D|network-ssd|network-hdd|network-ssd-nonreplicated|network-ssd-io-m3'
  _globals['_DISKSPEC'].fields_by_name['disk_size']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['disk_size']._serialized_options = b'\372\3071\0170-4398046511104'
  _globals['_IPVERSION']._serialized_start=3872
  _globals['_IPVERSION']._serialized_end=3931
  _globals['_NODE']._serialized_start=120
  _globals['_NODE']._serialized_end=858
  _globals['_NODE_KUBERNETESSTATUS']._serialized_start=357
  _globals['_NODE_KUBERNETESSTATUS']._serialized_end=546
  _globals['_NODE_CLOUDSTATUS']._serialized_start=548
  _globals['_NODE_CLOUDSTATUS']._serialized_end=613
  _globals['_NODE_SPEC']._serialized_start=615
  _globals['_NODE_SPEC']._serialized_end=721
  _globals['_NODE_STATUS']._serialized_start=724
  _globals['_NODE_STATUS']._serialized_end=858
  _globals['_CONDITION']._serialized_start=861
  _globals['_CONDITION']._serialized_end=1034
  _globals['_TAINT']._serialized_start=1037
  _globals['_TAINT']._serialized_end=1214
  _globals['_TAINT_EFFECT']._serialized_start=1125
  _globals['_TAINT_EFFECT']._serialized_end=1214
  _globals['_ATTACHEDVOLUME']._serialized_start=1216
  _globals['_ATTACHEDVOLUME']._serialized_end=1276
  _globals['_NODETEMPLATE']._serialized_start=1279
  _globals['_NODETEMPLATE']._serialized_end=2780
  _globals['_NODETEMPLATE_LABELSENTRY']._serialized_start=2285
  _globals['_NODETEMPLATE_LABELSENTRY']._serialized_end=2330
  _globals['_NODETEMPLATE_METADATAENTRY']._serialized_start=2332
  _globals['_NODETEMPLATE_METADATAENTRY']._serialized_end=2379
  _globals['_NODETEMPLATE_NETWORKSETTINGS']._serialized_start=2382
  _globals['_NODETEMPLATE_NETWORKSETTINGS']._serialized_end=2545
  _globals['_NODETEMPLATE_NETWORKSETTINGS_TYPE']._serialized_start=2477
  _globals['_NODETEMPLATE_NETWORKSETTINGS_TYPE']._serialized_end=2545
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS']._serialized_start=2548
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS']._serialized_end=2717
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS_TYPE']._serialized_start=2661
  _globals['_NODETEMPLATE_CONTAINERRUNTIMESETTINGS_TYPE']._serialized_end=2717
  _globals['_NODETEMPLATE_CONTAINERNETWORKSETTINGS']._serialized_start=2719
  _globals['_NODETEMPLATE_CONTAINERNETWORKSETTINGS']._serialized_end=2762
  _globals['_GPUSETTINGS']._serialized_start=2783
  _globals['_GPUSETTINGS']._serialized_end=2978
  _globals['_GPUSETTINGS_GPUENVIRONMENT']._serialized_start=2896
  _globals['_GPUSETTINGS_GPUENVIRONMENT']._serialized_end=2978
  _globals['_NETWORKINTERFACESPEC']._serialized_start=2981
  _globals['_NETWORKINTERFACESPEC']._serialized_end=3193
  _globals['_NODEADDRESSSPEC']._serialized_start=3196
  _globals['_NODEADDRESSSPEC']._serialized_end=3342
  _globals['_DNSRECORDSPEC']._serialized_start=3344
  _globals['_DNSRECORDSPEC']._serialized_end=3439
  _globals['_ONETOONENATSPEC']._serialized_start=3441
  _globals['_ONETOONENATSPEC']._serialized_end=3510
  _globals['_RESOURCESSPEC']._serialized_start=3512
  _globals['_RESOURCESSPEC']._serialized_end=3633
  _globals['_DISKSPEC']._serialized_start=3636
  _globals['_DISKSPEC']._serialized_end=3782
  _globals['_SCHEDULINGPOLICY']._serialized_start=3784
  _globals['_SCHEDULINGPOLICY']._serialized_end=3823
  _globals['_PLACEMENTPOLICY']._serialized_start=3825
  _globals['_PLACEMENTPOLICY']._serialized_end=3870
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.points_pb2
import yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.summarization_pb2
import yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2
import yandex.cloud.speechsense.v1.analysis.transcription_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FieldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FieldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FieldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FIELD_TYPE_UNSPECIFIED: _FieldType.ValueType  # 0
    FIELD_TYPE_STRING: _FieldType.ValueType  # 1
    FIELD_TYPE_NUMBER: _FieldType.ValueType  # 2
    FIELD_TYPE_DECIMAL: _FieldType.ValueType  # 3
    FIELD_TYPE_BOOLEAN: _FieldType.ValueType  # 4
    FIELD_TYPE_DATE: _FieldType.ValueType  # 5
    FIELD_TYPE_JSON: _FieldType.ValueType  # 6

class FieldType(_FieldType, metaclass=_FieldTypeEnumTypeWrapper):
    """connection field type"""

FIELD_TYPE_UNSPECIFIED: FieldType.ValueType  # 0
FIELD_TYPE_STRING: FieldType.ValueType  # 1
FIELD_TYPE_NUMBER: FieldType.ValueType  # 2
FIELD_TYPE_DECIMAL: FieldType.ValueType  # 3
FIELD_TYPE_BOOLEAN: FieldType.ValueType  # 4
FIELD_TYPE_DATE: FieldType.ValueType  # 5
FIELD_TYPE_JSON: FieldType.ValueType  # 6
global___FieldType = FieldType

class _ProcessingState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProcessingStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ProcessingState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROCESSING_STATE_UNSPECIFIED: _ProcessingState.ValueType  # 0
    PROCESSING_STATE_NOT_STARTED: _ProcessingState.ValueType  # 1
    PROCESSING_STATE_PROCESSING: _ProcessingState.ValueType  # 2
    PROCESSING_STATE_SUCCESS: _ProcessingState.ValueType  # 3
    PROCESSING_STATE_FAILED: _ProcessingState.ValueType  # 4

class ProcessingState(_ProcessingState, metaclass=_ProcessingStateEnumTypeWrapper): ...

PROCESSING_STATE_UNSPECIFIED: ProcessingState.ValueType  # 0
PROCESSING_STATE_NOT_STARTED: ProcessingState.ValueType  # 1
PROCESSING_STATE_PROCESSING: ProcessingState.ValueType  # 2
PROCESSING_STATE_SUCCESS: ProcessingState.ValueType  # 3
PROCESSING_STATE_FAILED: ProcessingState.ValueType  # 4
global___ProcessingState = ProcessingState

class _Algorithm:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Algorithm.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALGORITHM_UNSPECIFIED: _Algorithm.ValueType  # 0
    ALGORITHM_SPEECHKIT: _Algorithm.ValueType  # 1
    ALGORITHM_YGPT: _Algorithm.ValueType  # 2
    ALGORITHM_CLASSIFIER: _Algorithm.ValueType  # 3
    ALGORITHM_SUMMARIZATION: _Algorithm.ValueType  # 4
    ALGORITHM_EMBEDDING: _Algorithm.ValueType  # 5
    ALGORITHM_STATISTICS: _Algorithm.ValueType  # 6

class Algorithm(_Algorithm, metaclass=_AlgorithmEnumTypeWrapper): ...

ALGORITHM_UNSPECIFIED: Algorithm.ValueType  # 0
ALGORITHM_SPEECHKIT: Algorithm.ValueType  # 1
ALGORITHM_YGPT: Algorithm.ValueType  # 2
ALGORITHM_CLASSIFIER: Algorithm.ValueType  # 3
ALGORITHM_SUMMARIZATION: Algorithm.ValueType  # 4
ALGORITHM_EMBEDDING: Algorithm.ValueType  # 5
ALGORITHM_STATISTICS: Algorithm.ValueType  # 6
global___Algorithm = Algorithm

@typing.final
class Talk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PROJECT_IDS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    TALK_FIELDS_FIELD_NUMBER: builtins.int
    TRANSCRIPTION_FIELD_NUMBER: builtins.int
    SPEECH_STATISTICS_FIELD_NUMBER: builtins.int
    SILENCE_STATISTICS_FIELD_NUMBER: builtins.int
    INTERRUPTS_STATISTICS_FIELD_NUMBER: builtins.int
    CONVERSATION_STATISTICS_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFIERS_FIELD_NUMBER: builtins.int
    SUMMARIZATION_FIELD_NUMBER: builtins.int
    TALK_STATE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """talk id"""
    organization_id: builtins.str
    space_id: builtins.str
    connection_id: builtins.str
    created_by: builtins.str
    """audition info"""
    modified_by: builtins.str
    @property
    def project_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def talk_fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Field]:
        """key-value representation of talk fields with values"""

    @property
    def transcription(self) -> yandex.cloud.speechsense.v1.analysis.transcription_pb2.Transcription:
        """various ml analysis results"""

    @property
    def speech_statistics(self) -> yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2.SpeechStatistics: ...
    @property
    def silence_statistics(self) -> yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2.SilenceStatistics: ...
    @property
    def interrupts_statistics(self) -> yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2.InterruptsStatistics: ...
    @property
    def conversation_statistics(self) -> yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2.ConversationStatistics: ...
    @property
    def points(self) -> yandex.cloud.speechsense.v1.analysis.points_pb2.Points: ...
    @property
    def text_classifiers(self) -> yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2.TextClassifiers: ...
    @property
    def summarization(self) -> yandex.cloud.speechsense.v1.analysis.summarization_pb2.Summarization: ...
    @property
    def talk_state(self) -> global___TalkState: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        space_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        project_ids: collections.abc.Iterable[builtins.str] | None = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_by: builtins.str = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        talk_fields: collections.abc.Iterable[global___Field] | None = ...,
        transcription: yandex.cloud.speechsense.v1.analysis.transcription_pb2.Transcription | None = ...,
        speech_statistics: yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2.SpeechStatistics | None = ...,
        silence_statistics: yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2.SilenceStatistics | None = ...,
        interrupts_statistics: yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2.InterruptsStatistics | None = ...,
        conversation_statistics: yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2.ConversationStatistics | None = ...,
        points: yandex.cloud.speechsense.v1.analysis.points_pb2.Points | None = ...,
        text_classifiers: yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2.TextClassifiers | None = ...,
        summarization: yandex.cloud.speechsense.v1.analysis.summarization_pb2.Summarization | None = ...,
        talk_state: global___TalkState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation_statistics", b"conversation_statistics", "created_at", b"created_at", "interrupts_statistics", b"interrupts_statistics", "modified_at", b"modified_at", "points", b"points", "silence_statistics", b"silence_statistics", "speech_statistics", b"speech_statistics", "summarization", b"summarization", "talk_state", b"talk_state", "text_classifiers", b"text_classifiers", "transcription", b"transcription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "conversation_statistics", b"conversation_statistics", "created_at", b"created_at", "created_by", b"created_by", "id", b"id", "interrupts_statistics", b"interrupts_statistics", "modified_at", b"modified_at", "modified_by", b"modified_by", "organization_id", b"organization_id", "points", b"points", "project_ids", b"project_ids", "silence_statistics", b"silence_statistics", "space_id", b"space_id", "speech_statistics", b"speech_statistics", "summarization", b"summarization", "talk_fields", b"talk_fields", "talk_state", b"talk_state", "text_classifiers", b"text_classifiers", "transcription", b"transcription"]) -> None: ...

global___Talk = Talk

@typing.final
class TalkState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROCESSING_STATE_FIELD_NUMBER: builtins.int
    ALGORITHM_PROCESSING_INFOS_FIELD_NUMBER: builtins.int
    processing_state: global___ProcessingState.ValueType
    @property
    def algorithm_processing_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlgorithmProcessingInfo]: ...
    def __init__(
        self,
        *,
        processing_state: global___ProcessingState.ValueType = ...,
        algorithm_processing_infos: collections.abc.Iterable[global___AlgorithmProcessingInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["algorithm_processing_infos", b"algorithm_processing_infos", "processing_state", b"processing_state"]) -> None: ...

global___TalkState = TalkState

@typing.final
class Field(google.protobuf.message.Message):
    """connection field value"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of the field"""
    value: builtins.str
    """field value"""
    type: global___FieldType.ValueType
    """field type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        type: global___FieldType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "type", b"type", "value", b"value"]) -> None: ...

global___Field = Field

@typing.final
class AlgorithmProcessingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    PROCESSING_STATE_FIELD_NUMBER: builtins.int
    algorithm: global___Algorithm.ValueType
    processing_state: global___ProcessingState.ValueType
    def __init__(
        self,
        *,
        algorithm: global___Algorithm.ValueType = ...,
        processing_state: global___ProcessingState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["algorithm", b"algorithm", "processing_state", b"processing_state"]) -> None: ...

global___AlgorithmProcessingInfo = AlgorithmProcessingInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/searchapi/v2/img_search_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/searchapi/v2/img_search_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.searchapi.v2 import search_query_pb2 as yandex_dot_cloud_dot_searchapi_dot_v2_dot_search__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/searchapi/v2/img_search_service.proto\x12\x19yandex.cloud.searchapi.v2\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/searchapi/v2/search_query.proto\x1a\x1cgoogle/api/annotations.proto\"\x80\x08\n\tImageSpec\x12@\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x30.yandex.cloud.searchapi.v2.ImageSpec.ImageFormat\x12<\n\x04size\x18\x02 \x01(\x0e\x32..yandex.cloud.searchapi.v2.ImageSpec.ImageSize\x12J\n\x0borientation\x18\x03 \x01(\x0e\x32\x35.yandex.cloud.searchapi.v2.ImageSpec.ImageOrientation\x12>\n\x05\x63olor\x18\x04 \x01(\x0e\x32/.yandex.cloud.searchapi.v2.ImageSpec.ImageColor\"n\n\x0bImageFormat\x12\x1c\n\x18IMAGE_FORMAT_UNSPECIFIED\x10\x00\x12\x15\n\x11IMAGE_FORMAT_JPEG\x10\x01\x12\x14\n\x10IMAGE_FORMAT_GIF\x10\x02\x12\x14\n\x10IMAGE_FORMAT_PNG\x10\x03\"\x95\x01\n\x10ImageOrientation\x12!\n\x1dIMAGE_ORIENTATION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aIMAGE_ORIENTATION_VERTICAL\x10\x01\x12 \n\x1cIMAGE_ORIENTATION_HORIZONTAL\x10\x02\x12\x1c\n\x18IMAGE_ORIENTATION_SQUARE\x10\x03\"\xb2\x01\n\tImageSize\x12\x1a\n\x16IMAGE_SIZE_UNSPECIFIED\x10\x00\x12\x17\n\x13IMAGE_SIZE_ENORMOUS\x10\x01\x12\x14\n\x10IMAGE_SIZE_LARGE\x10\x02\x12\x15\n\x11IMAGE_SIZE_MEDIUM\x10\x03\x12\x14\n\x10IMAGE_SIZE_SMALL\x10\x04\x12\x13\n\x0fIMAGE_SIZE_TINY\x10\x05\x12\x18\n\x14IMAGE_SIZE_WALLPAPER\x10\x06\"\xa9\x02\n\nImageColor\x12\x1b\n\x17IMAGE_COLOR_UNSPECIFIED\x10\x00\x12\x15\n\x11IMAGE_COLOR_COLOR\x10\x01\x12\x19\n\x15IMAGE_COLOR_GRAYSCALE\x10\x02\x12\x13\n\x0fIMAGE_COLOR_RED\x10\x03\x12\x16\n\x12IMAGE_COLOR_ORANGE\x10\x04\x12\x16\n\x12IMAGE_COLOR_YELLOW\x10\x05\x12\x15\n\x11IMAGE_COLOR_GREEN\x10\x06\x12\x14\n\x10IMAGE_COLOR_CYAN\x10\x07\x12\x14\n\x10IMAGE_COLOR_BLUE\x10\x08\x12\x16\n\x12IMAGE_COLOR_VIOLET\x10\t\x12\x15\n\x11IMAGE_COLOR_WHITE\x10\n\x12\x15\n\x11IMAGE_COLOR_BLACK\x10\x0b\"\xf6\x01\n\x12ImageSearchRequest\x12;\n\x05query\x18\x01 \x01(\x0b\x32&.yandex.cloud.searchapi.v2.SearchQueryB\x04\xe8\xc7\x31\x01\x12\x38\n\nimage_spec\x18\x02 \x01(\x0b\x32$.yandex.cloud.searchapi.v2.ImageSpec\x12\x0c\n\x04site\x18\x03 \x01(\t\x12\x1f\n\x0c\x64ocs_on_page\x18\x04 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x12\x1b\n\tfolder_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\nuser_agent\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=300\"-\n\x13ImageSearchResponse\x12\x16\n\x08raw_data\x18\x01 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\"\x9a\x02\n\x19ImageSearchByImageRequest\x12\x18\n\x04site\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x1b\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x03url\x18\x03 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024H\x00\x12!\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x42\x11\xe8\xc7\x31\x01\x8a\xc8\x31\t<=3145728H\x00\x12\x1c\n\x02id\x18\x05 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024H\x00\x12\x15\n\x04page\x18\x06 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x0b\x66\x61mily_mode\x18\x07 \x01(\x0e\x32\x31.yandex.cloud.searchapi.v2.SearchQuery.FamilyModeB\x07\n\x05image\"\xda\x02\n\x1aImageSearchByImageResponse\x12O\n\x06images\x18\x01 \x03(\x0b\x32?.yandex.cloud.searchapi.v2.ImageSearchByImageResponse.ImageInfo\x12\x0c\n\x04page\x18\x02 \x01(\x03\x12\x10\n\x08max_page\x18\x03 \x01(\x03\x12\n\n\x02id\x18\x04 \x01(\t\x1a\xbe\x01\n\tImageInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12@\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x30.yandex.cloud.searchapi.v2.ImageSpec.ImageFormat\x12\r\n\x05width\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x03\x12\x0f\n\x07passage\x18\x05 \x01(\t\x12\x0c\n\x04host\x18\x06 \x01(\t\x12\x12\n\npage_title\x18\x07 \x01(\t\x12\x10\n\x08page_url\x18\x08 \x01(\t2\xc0\x02\n\x12ImageSearchService\x12\x84\x01\n\x06Search\x12-.yandex.cloud.searchapi.v2.ImageSearchRequest\x1a..yandex.cloud.searchapi.v2.ImageSearchResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/image/search:\x01*\x12\xa2\x01\n\rSearchByImage\x12\x34.yandex.cloud.searchapi.v2.ImageSearchByImageRequest\x1a\x35.yandex.cloud.searchapi.v2.ImageSearchByImageResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v2/image/search_by_image:\x01*Be\n\x1ayandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.searchapi.v2.img_search_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapi'
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['query']._serialized_options = b'\350\3071\001'
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['docs_on_page']._loaded_options = None
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['docs_on_page']._serialized_options = b'\372\3071\0051-100'
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['user_agent']._loaded_options = None
  _globals['_IMAGESEARCHREQUEST'].fields_by_name['user_agent']._serialized_options = b'\212\3101\005<=300'
  _globals['_IMAGESEARCHRESPONSE'].fields_by_name['raw_data']._loaded_options = None
  _globals['_IMAGESEARCHRESPONSE'].fields_by_name['raw_data']._serialized_options = b'\350\3071\001'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['site']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['site']._serialized_options = b'\212\3101\006<=1024'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['url']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['data']._serialized_options = b'\350\3071\001\212\3101\t<=3145728'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['page']._loaded_options = None
  _globals['_IMAGESEARCHBYIMAGEREQUEST'].fields_by_name['page']._serialized_options = b'\372\3071\003>=0'
  _globals['_IMAGESEARCHSERVICE'].methods_by_name['Search']._loaded_options = None
  _globals['_IMAGESEARCHSERVICE'].methods_by_name['Search']._serialized_options = b'\202\323\344\223\002\025\"\020/v2/image/search:\001*'
  _globals['_IMAGESEARCHSERVICE'].methods_by_name['SearchByImage']._loaded_options = None
  _globals['_IMAGESEARCHSERVICE'].methods_by_name['SearchByImage']._serialized_options = b'\202\323\344\223\002\036\"\031/v2/image/search_by_image:\001*'
  _globals['_IMAGESPEC']._serialized_start=189
  _globals['_IMAGESPEC']._serialized_end=1213
  _globals['_IMAGESPEC_IMAGEFORMAT']._serialized_start=470
  _globals['_IMAGESPEC_IMAGEFORMAT']._serialized_end=580
  _globals['_IMAGESPEC_IMAGEORIENTATION']._serialized_start=583
  _globals['_IMAGESPEC_IMAGEORIENTATION']._serialized_end=732
  _globals['_IMAGESPEC_IMAGESIZE']._serialized_start=735
  _globals['_IMAGESPEC_IMAGESIZE']._serialized_end=913
  _globals['_IMAGESPEC_IMAGECOLOR']._serialized_start=916
  _globals['_IMAGESPEC_IMAGECOLOR']._serialized_end=1213
  _globals['_IMAGESEARCHREQUEST']._serialized_start=1216
  _globals['_IMAGESEARCHREQUEST']._serialized_end=1462
  _globals['_IMAGESEARCHRESPONSE']._serialized_start=1464
  _globals['_IMAGESEARCHRESPONSE']._serialized_end=1509
  _globals['_IMAGESEARCHBYIMAGEREQUEST']._serialized_start=1512
  _globals['_IMAGESEARCHBYIMAGEREQUEST']._serialized_end=1794
  _globals['_IMAGESEARCHBYIMAGERESPONSE']._serialized_start=1797
  _globals['_IMAGESEARCHBYIMAGERESPONSE']._serialized_end=2143
  _globals['_IMAGESEARCHBYIMAGERESPONSE_IMAGEINFO']._serialized_start=1953
  _globals['_IMAGESEARCHBYIMAGERESPONSE_IMAGEINFO']._serialized_end=2143
  _globals['_IMAGESEARCHSERVICE']._serialized_start=2146
  _globals['_IMAGESEARCHSERVICE']._serialized_end=2466
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cdn.v1.origin_group_pb2
import yandex.cloud.cdn.v1.origin_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOriginGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    origin_group_id: builtins.int
    """ID of the origin group to return.

    To get a origin group ID, make a [OriginGroupService.List] request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "origin_group_id", b"origin_group_id"]) -> None: ...

global___GetOriginGroupRequest = GetOriginGroupRequest

@typing.final
class ListOriginGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to.."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListOriginGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListOriginGroupsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOriginGroupsRequest = ListOriginGroupsRequest

@typing.final
class ListOriginGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """[next_page_token] token allows you to get the next page of results for list requests.
    If the number of results is larger than [ListOriginGroupsRequest.page_size], use
    the [next_page_token] as the value for the [ListOriginGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def origin_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup]:
        """List of all Origin Groups associated with folder."""

    def __init__(
        self,
        *,
        origin_groups: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "origin_groups", b"origin_groups"]) -> None: ...

global___ListOriginGroupsResponse = ListOriginGroupsResponse

@typing.final
class CreateOriginGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USE_NEXT_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    name: builtins.str
    """Name of the origin group."""
    provider_type: builtins.str
    """Set up origin group provider

    It has two possible values:

    ourcdn - Based on Yandex technologies
    gcore - Based on an external partner infrastructure

    Default value: ourcdn
    """
    @property
    def use_next(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This option have two possible conditions:
         true - The option is active. In case the origin responds with 4XX or 5XX codes,
                use the next origin from the list.
         false - The option is disabled.

         default value is true
        """

    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_pb2.OriginParams]:
        """List of origins: IP addresses or Domain names of your origins and the port
        (if custom).
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        use_next: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        origins: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_pb2.OriginParams] | None = ...,
        provider_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["use_next", b"use_next"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "name", b"name", "origins", b"origins", "provider_type", b"provider_type", "use_next", b"use_next"]) -> None: ...

global___CreateOriginGroupRequest = CreateOriginGroupRequest

@typing.final
class CreateOriginGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    origin_group_id: builtins.int
    """ID of created origin group."""
    def __init__(
        self,
        *,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id"]) -> None: ...

global___CreateOriginGroupMetadata = CreateOriginGroupMetadata

@typing.final
class UpdateOriginGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    USE_NEXT_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    origin_group_id: builtins.int
    """ID of the origin group."""
    @property
    def group_name(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Name of the origin group."""

    @property
    def use_next(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This option have two possible values:

          True - The option is active. In case the origin responds with 4XX or 5XX
                 codes, use the next origin from the list.
          False - The option is disabled.
        """

    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_pb2.OriginParams]:
        """List of origins: IP addresses or Domain names of your origins and the port
        (if custom).
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_group_id: builtins.int = ...,
        group_name: google.protobuf.wrappers_pb2.StringValue | None = ...,
        use_next: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        origins: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_pb2.OriginParams] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group_name", b"group_name", "use_next", b"use_next"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "group_name", b"group_name", "origin_group_id", b"origin_group_id", "origins", b"origins", "use_next", b"use_next"]) -> None: ...

global___UpdateOriginGroupRequest = UpdateOriginGroupRequest

@typing.final
class UpdateOriginGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    origin_group_id: builtins.int
    """ID of the origin group."""
    def __init__(
        self,
        *,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id"]) -> None: ...

global___UpdateOriginGroupMetadata = UpdateOriginGroupMetadata

@typing.final
class DeleteOriginGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    origin_group_id: builtins.int
    """ID of the origin group."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "origin_group_id", b"origin_group_id"]) -> None: ...

global___DeleteOriginGroupRequest = DeleteOriginGroupRequest

@typing.final
class DeleteOriginGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    origin_group_id: builtins.int
    """ID of the origin group."""
    def __init__(
        self,
        *,
        origin_group_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id"]) -> None: ...

global___DeleteOriginGroupMetadata = DeleteOriginGroupMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/disk.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/disk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/baremetal/v1alpha/disk.proto\x12\x1eyandex.cloud.baremetal.v1alpha\"a\n\x04\x44isk\x12\n\n\x02id\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.yandex.cloud.baremetal.v1alpha.DiskDriveType\x12\x10\n\x08size_gib\x18\x03 \x01(\x03*L\n\rDiskDriveType\x12\x1f\n\x1b\x44ISK_DRIVE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03HDD\x10\x01\x12\x07\n\x03SSD\x10\x02\x12\x08\n\x04NVME\x10\x03\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.disk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_DISKDRIVETYPE']._serialized_start=176
  _globals['_DISKDRIVETYPE']._serialized_end=252
  _globals['_DISK']._serialized_start=77
  _globals['_DISK']._serialized_end=174
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.datasphere.v2.community_pb2
import yandex.cloud.datasphere.v2.community_service_pb2
import yandex.cloud.datasphere.v2.restrictions_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CommunityServiceStub:
    """A set of methods for managing Community resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.CreateCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates community in specified organization."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRequest,
        yandex.cloud.datasphere.v2.community_pb2.Community,
    ]
    """Returns community."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.UpdateCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified community."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.DeleteCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified community."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesRequest,
        yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesResponse,
    ]
    """List communities in specified organization."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for specified community."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for specified community."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for specified community."""

    AddResource: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.AddCommunityResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds shared resource to community"""

    RemoveResource: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.RemoveCommunityResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes shared resource from community"""

    GetRestrictionsMeta: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse,
    ]
    """Get meta information about available restrictions."""

    GetRestrictions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRestrictionsRequest,
        yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse,
    ]
    """Get current community restrictions."""

    SetRestrictions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.SetCommunityRestrictionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set community restrictions."""

class CommunityServiceAsyncStub:
    """A set of methods for managing Community resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.CreateCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates community in specified organization."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRequest,
        yandex.cloud.datasphere.v2.community_pb2.Community,
    ]
    """Returns community."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.UpdateCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified community."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.DeleteCommunityRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified community."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesRequest,
        yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesResponse,
    ]
    """List communities in specified organization."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for specified community."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for specified community."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for specified community."""

    AddResource: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.AddCommunityResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds shared resource to community"""

    RemoveResource: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.RemoveCommunityResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes shared resource from community"""

    GetRestrictionsMeta: grpc.aio.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse,
    ]
    """Get meta information about available restrictions."""

    GetRestrictions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRestrictionsRequest,
        yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse,
    ]
    """Get current community restrictions."""

    SetRestrictions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.community_service_pb2.SetCommunityRestrictionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set community restrictions."""

class CommunityServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Community resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.CreateCommunityRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates community in specified organization."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.community_pb2.Community, collections.abc.Awaitable[yandex.cloud.datasphere.v2.community_pb2.Community]]:
        """Returns community."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.UpdateCommunityRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates specified community."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.DeleteCommunityRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes specified community."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.community_service_pb2.ListCommunitiesResponse]]:
        """List communities in specified organization."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for specified community."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for specified community."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for specified community."""

    @abc.abstractmethod
    def AddResource(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.AddCommunityResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds shared resource to community"""

    @abc.abstractmethod
    def RemoveResource(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.RemoveCommunityResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes shared resource from community"""

    @abc.abstractmethod
    def GetRestrictionsMeta(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse]]:
        """Get meta information about available restrictions."""

    @abc.abstractmethod
    def GetRestrictions(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.GetCommunityRestrictionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse]]:
        """Get current community restrictions."""

    @abc.abstractmethod
    def SetRestrictions(
        self,
        request: yandex.cloud.datasphere.v2.community_service_pb2.SetCommunityRestrictionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set community restrictions."""

def add_CommunityServiceServicer_to_server(servicer: CommunityServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TuningError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TuningError._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: TuningError._Type.ValueType  # 0
        PUBLIC: TuningError._Type.ValueType  # 1
        INTERNAL: TuningError._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: TuningError.Type.ValueType  # 0
    PUBLIC: TuningError.Type.ValueType  # 1
    INTERNAL: TuningError.Type.ValueType  # 2

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    message: builtins.str
    type: global___TuningError.Type.ValueType
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
        message: builtins.str = ...,
        type: global___TuningError.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "tuning_task_id", b"tuning_task_id", "type", b"type"]) -> None: ...

global___TuningError = TuningError



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DatabaseEngine:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DatabaseEngineEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DatabaseEngine.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DATABASE_ENGINE_UNSPECIFIED: _DatabaseEngine.ValueType  # 0
    DATABASE_ENGINE_ATOMIC: _DatabaseEngine.ValueType  # 1
    DATABASE_ENGINE_REPLICATED: _DatabaseEngine.ValueType  # 2

class DatabaseEngine(_DatabaseEngine, metaclass=_DatabaseEngineEnumTypeWrapper): ...

DATABASE_ENGINE_UNSPECIFIED: DatabaseEngine.ValueType  # 0
DATABASE_ENGINE_ATOMIC: DatabaseEngine.ValueType  # 1
DATABASE_ENGINE_REPLICATED: DatabaseEngine.ValueType  # 2
global___DatabaseEngine = DatabaseEngine

@typing.final
class Database(google.protobuf.message.Message):
    """A ClickHouse Database resource. For more information, see the
    [Developer's Guide](/docs/managed-clickhouse/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    cluster_id: builtins.str
    """ID of the ClickHouse cluster that the database belongs to."""
    engine: global___DatabaseEngine.ValueType
    """Database engine. For details, see [ClickHouse documentation](https://clickhouse.com/docs/engines/database-engines)."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        engine: global___DatabaseEngine.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "engine", b"engine", "name", b"name"]) -> None: ...

global___Database = Database

@typing.final
class DatabaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the ClickHouse database. 1-63 characters long."""
    engine: global___DatabaseEngine.ValueType
    """Database engine. For details, see [ClickHouse documentation](https://clickhouse.com/docs/engines/database-engines)."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        engine: global___DatabaseEngine.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["engine", b"engine", "name", b"name"]) -> None: ...

global___DatabaseSpec = DatabaseSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ydb.v1.backup_pb2
import yandex.cloud.ydb.v1.database_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MoveDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    """ID of the YDB instance to move."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "destination_folder_id", b"destination_folder_id"]) -> None: ...

global___MoveDatabaseRequest = MoveDatabaseRequest

@typing.final
class MoveDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___MoveDatabaseMetadata = MoveDatabaseMetadata

@typing.final
class RestoreBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    PATHS_TO_RESTORE_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """Required. ID of the YDB backup."""
    database_id: builtins.str
    """Required. ID of the YDB database."""
    target_path: builtins.str
    """Specify target path."""
    @property
    def paths_to_restore(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Specify paths to restore.
        If empty, all paths will restored by default.
        """

    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        database_id: builtins.str = ...,
        paths_to_restore: collections.abc.Iterable[builtins.str] | None = ...,
        target_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "database_id", b"database_id", "paths_to_restore", b"paths_to_restore", "target_path", b"target_path"]) -> None: ...

global___RestoreBackupRequest = RestoreBackupRequest

@typing.final
class RestoreBackupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    database_id: builtins.str
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "database_id", b"database_id"]) -> None: ...

global___RestoreBackupMetadata = RestoreBackupMetadata

@typing.final
class BackupDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    BACKUP_SETTINGS_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    @property
    def backup_settings(self) -> yandex.cloud.ydb.v1.backup_pb2.BackupSettings:
        """custom backup options, if required."""

    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        backup_settings: yandex.cloud.ydb.v1.backup_pb2.BackupSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_settings", b"backup_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_settings", b"backup_settings", "database_id", b"database_id"]) -> None: ...

global___BackupDatabaseRequest = BackupDatabaseRequest

@typing.final
class BackupDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    database_id: builtins.str
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "database_id", b"database_id"]) -> None: ...

global___BackupDatabaseMetadata = BackupDatabaseMetadata

@typing.final
class StartDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id"]) -> None: ...

global___StartDatabaseRequest = StartDatabaseRequest

@typing.final
class StartDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___StartDatabaseMetadata = StartDatabaseMetadata

@typing.final
class StopDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id"]) -> None: ...

global___StopDatabaseRequest = StopDatabaseRequest

@typing.final
class StopDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___StopDatabaseMetadata = StopDatabaseMetadata

@typing.final
class GetDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    """Required. ID of the YDB cluster."""
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id"]) -> None: ...

global___GetDatabaseRequest = GetDatabaseRequest

@typing.final
class ListDatabasesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListDatabases requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListDatabases
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDatabasesRequest = ListDatabasesRequest

@typing.final
class ListDatabasesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListDatabases requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListDatabases request. Subsequent ListDatabases
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ydb.v1.database_pb2.Database]: ...
    def __init__(
        self,
        *,
        databases: collections.abc.Iterable[yandex.cloud.ydb.v1.database_pb2.Database] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["databases", b"databases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDatabasesResponse = ListDatabasesResponse

@typing.final
class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONFIG_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ZONAL_DATABASE_FIELD_NUMBER: builtins.int
    REGIONAL_DATABASE_FIELD_NUMBER: builtins.int
    DEDICATED_DATABASE_FIELD_NUMBER: builtins.int
    SERVERLESS_DATABASE_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    BACKUP_CONFIG_FIELD_NUMBER: builtins.int
    MONITORING_CONFIG_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    resource_preset_id: builtins.str
    network_id: builtins.str
    assign_public_ips: builtins.bool
    location_id: builtins.str
    deletion_protection: builtins.bool
    @property
    def storage_config(self) -> yandex.cloud.ydb.v1.database_pb2.StorageConfig: ...
    @property
    def scale_policy(self) -> yandex.cloud.ydb.v1.database_pb2.ScalePolicy: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def zonal_database(self) -> yandex.cloud.ydb.v1.database_pb2.ZonalDatabase:
        """deprecated field"""

    @property
    def regional_database(self) -> yandex.cloud.ydb.v1.database_pb2.RegionalDatabase:
        """deprecated field"""

    @property
    def dedicated_database(self) -> yandex.cloud.ydb.v1.database_pb2.DedicatedDatabase: ...
    @property
    def serverless_database(self) -> yandex.cloud.ydb.v1.database_pb2.ServerlessDatabase: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def backup_config(self) -> yandex.cloud.ydb.v1.backup_pb2.BackupConfig: ...
    @property
    def monitoring_config(self) -> yandex.cloud.ydb.v1.database_pb2.MonitoringConfig: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        resource_preset_id: builtins.str = ...,
        storage_config: yandex.cloud.ydb.v1.database_pb2.StorageConfig | None = ...,
        scale_policy: yandex.cloud.ydb.v1.database_pb2.ScalePolicy | None = ...,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        zonal_database: yandex.cloud.ydb.v1.database_pb2.ZonalDatabase | None = ...,
        regional_database: yandex.cloud.ydb.v1.database_pb2.RegionalDatabase | None = ...,
        dedicated_database: yandex.cloud.ydb.v1.database_pb2.DedicatedDatabase | None = ...,
        serverless_database: yandex.cloud.ydb.v1.database_pb2.ServerlessDatabase | None = ...,
        assign_public_ips: builtins.bool = ...,
        location_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_config: yandex.cloud.ydb.v1.backup_pb2.BackupConfig | None = ...,
        monitoring_config: yandex.cloud.ydb.v1.database_pb2.MonitoringConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_config", b"backup_config", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "monitoring_config", b"monitoring_config", "regional_database", b"regional_database", "scale_policy", b"scale_policy", "serverless_database", b"serverless_database", "storage_config", b"storage_config", "zonal_database", b"zonal_database"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ips", b"assign_public_ips", "backup_config", b"backup_config", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "location_id", b"location_id", "monitoring_config", b"monitoring_config", "name", b"name", "network_id", b"network_id", "regional_database", b"regional_database", "resource_preset_id", b"resource_preset_id", "scale_policy", b"scale_policy", "security_group_ids", b"security_group_ids", "serverless_database", b"serverless_database", "storage_config", b"storage_config", "subnet_ids", b"subnet_ids", "zonal_database", b"zonal_database"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["database_type", b"database_type"]) -> typing.Literal["zonal_database", "regional_database", "dedicated_database", "serverless_database"] | None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

@typing.final
class CreateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    """Required. ID of the YDB cluster."""
    database_name: builtins.str
    """Required. Name of the creating database."""
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___CreateDatabaseMetadata = CreateDatabaseMetadata

@typing.final
class UpdateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONFIG_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ZONAL_DATABASE_FIELD_NUMBER: builtins.int
    REGIONAL_DATABASE_FIELD_NUMBER: builtins.int
    DEDICATED_DATABASE_FIELD_NUMBER: builtins.int
    SERVERLESS_DATABASE_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    BACKUP_CONFIG_FIELD_NUMBER: builtins.int
    MONITORING_CONFIG_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    database_id: builtins.str
    name: builtins.str
    description: builtins.str
    resource_preset_id: builtins.str
    network_id: builtins.str
    assign_public_ips: builtins.bool
    location_id: builtins.str
    deletion_protection: builtins.bool
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def storage_config(self) -> yandex.cloud.ydb.v1.database_pb2.StorageConfig: ...
    @property
    def scale_policy(self) -> yandex.cloud.ydb.v1.database_pb2.ScalePolicy: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def zonal_database(self) -> yandex.cloud.ydb.v1.database_pb2.ZonalDatabase: ...
    @property
    def regional_database(self) -> yandex.cloud.ydb.v1.database_pb2.RegionalDatabase: ...
    @property
    def dedicated_database(self) -> yandex.cloud.ydb.v1.database_pb2.DedicatedDatabase: ...
    @property
    def serverless_database(self) -> yandex.cloud.ydb.v1.database_pb2.ServerlessDatabase: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def backup_config(self) -> yandex.cloud.ydb.v1.backup_pb2.BackupConfig: ...
    @property
    def monitoring_config(self) -> yandex.cloud.ydb.v1.database_pb2.MonitoringConfig: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        database_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        resource_preset_id: builtins.str = ...,
        storage_config: yandex.cloud.ydb.v1.database_pb2.StorageConfig | None = ...,
        scale_policy: yandex.cloud.ydb.v1.database_pb2.ScalePolicy | None = ...,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        zonal_database: yandex.cloud.ydb.v1.database_pb2.ZonalDatabase | None = ...,
        regional_database: yandex.cloud.ydb.v1.database_pb2.RegionalDatabase | None = ...,
        dedicated_database: yandex.cloud.ydb.v1.database_pb2.DedicatedDatabase | None = ...,
        serverless_database: yandex.cloud.ydb.v1.database_pb2.ServerlessDatabase | None = ...,
        assign_public_ips: builtins.bool = ...,
        location_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_config: yandex.cloud.ydb.v1.backup_pb2.BackupConfig | None = ...,
        monitoring_config: yandex.cloud.ydb.v1.database_pb2.MonitoringConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_config", b"backup_config", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "monitoring_config", b"monitoring_config", "regional_database", b"regional_database", "scale_policy", b"scale_policy", "serverless_database", b"serverless_database", "storage_config", b"storage_config", "update_mask", b"update_mask", "zonal_database", b"zonal_database"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ips", b"assign_public_ips", "backup_config", b"backup_config", "database_id", b"database_id", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "location_id", b"location_id", "monitoring_config", b"monitoring_config", "name", b"name", "network_id", b"network_id", "regional_database", b"regional_database", "resource_preset_id", b"resource_preset_id", "scale_policy", b"scale_policy", "security_group_ids", b"security_group_ids", "serverless_database", b"serverless_database", "storage_config", b"storage_config", "subnet_ids", b"subnet_ids", "update_mask", b"update_mask", "zonal_database", b"zonal_database"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["database_type", b"database_type"]) -> typing.Literal["zonal_database", "regional_database", "dedicated_database", "serverless_database"] | None: ...

global___UpdateDatabaseRequest = UpdateDatabaseRequest

@typing.final
class UpdateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___UpdateDatabaseMetadata = UpdateDatabaseMetadata

@typing.final
class DeleteDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id"]) -> None: ...

global___DeleteDatabaseRequest = DeleteDatabaseRequest

@typing.final
class DeleteDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_id: builtins.str
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_id", b"database_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseMetadata = DeleteDatabaseMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/connection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.connectionmanager.v1 import mysql_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_mysql__pb2
from yandex.cloud.connectionmanager.v1 import postgresql_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_postgresql__pb2
from yandex.cloud.connectionmanager.v1 import mongodb_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_mongodb__pb2
from yandex.cloud.connectionmanager.v1 import clickhouse_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_clickhouse__pb2
from yandex.cloud.connectionmanager.v1 import redis_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_redis__pb2
from yandex.cloud.connectionmanager.v1 import trino_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_trino__pb2
from yandex.cloud.connectionmanager.v1 import valkey_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_valkey__pb2
from yandex.cloud.connectionmanager.v1 import opensearch_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_opensearch__pb2
from yandex.cloud.connectionmanager.v1 import greenplum_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_greenplum__pb2
from yandex.cloud.connectionmanager.v1 import kafka_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_kafka__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/connectionmanager/v1/connection.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/connectionmanager/v1/mysql.proto\x1a\x32yandex/cloud/connectionmanager/v1/postgresql.proto\x1a/yandex/cloud/connectionmanager/v1/mongodb.proto\x1a\x32yandex/cloud/connectionmanager/v1/clickhouse.proto\x1a-yandex/cloud/connectionmanager/v1/redis.proto\x1a-yandex/cloud/connectionmanager/v1/trino.proto\x1a.yandex/cloud/connectionmanager/v1/valkey.proto\x1a\x32yandex/cloud/connectionmanager/v1/opensearch.proto\x1a\x31yandex/cloud/connectionmanager/v1/greenplum.proto\x1a-yandex/cloud/connectionmanager/v1/kafka.proto\"\xf8\x05\n\x10\x43onnectionParams\x12M\n\npostgresql\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.PostgreSQLConnectionH\x00\x12\x43\n\x05mysql\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.MySQLConnectionH\x00\x12G\n\x07mongodb\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.MongoDBConnectionH\x00\x12M\n\nclickhouse\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.ClickHouseConnectionH\x00\x12\x43\n\x05kafka\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.KafkaConnectionH\x00\x12\x43\n\x05redis\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.RedisConnectionH\x00\x12M\n\nopensearch\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.OpenSearchConnectionH\x00\x12\x43\n\x05trino\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.TrinoConnectionH\x00\x12\x45\n\x06valkey\x18\t \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ValkeyConnectionH\x00\x12K\n\tgreenplum\x18\n \x01(\x0b\x32\x36.yandex.cloud.connectionmanager.v1.GreenplumConnectionH\x00\x42\x06\n\x04type\"D\n\rLockboxSecret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0enewest_version\x18\x03 \x01(\t\"\x9e\x04\n\nConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12I\n\x06labels\x18\x07 \x03(\x0b\x32\x39.yandex.cloud.connectionmanager.v1.Connection.LabelsEntry\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12\x43\n\x06params\x18\t \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x12J\n\x0elockbox_secret\x18\n \x01(\x0b\x32\x30.yandex.cloud.connectionmanager.v1.LockboxSecretH\x00\x12\x12\n\nis_managed\x18\x0c \x01(\x08\x12+\n\x07\x63\x61n_use\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06secretJ\x04\x08\x0b\x10\x0c*\xa5\x01\n\x06\x44\x42Type\x12\x17\n\x13\x44\x42_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\t\n\x05MYSQL\x10\x02\x12\x0e\n\nCLICKHOUSE\x10\x03\x12\x0b\n\x07MONGODB\x10\x04\x12\t\n\x05KAFKA\x10\x05\x12\t\n\x05REDIS\x10\x06\x12\x0e\n\nOPENSEARCH\x10\x07\x12\t\n\x05TRINO\x10\x08\x12\n\n\x06VALKEY\x10\t\x12\r\n\tGREENPLUM\x10\nB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_CONNECTION_LABELSENTRY']._loaded_options = None
  _globals['_CONNECTION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DBTYPE']._serialized_start=2025
  _globals['_DBTYPE']._serialized_end=2190
  _globals['_CONNECTIONPARAMS']._serialized_start=647
  _globals['_CONNECTIONPARAMS']._serialized_end=1407
  _globals['_LOCKBOXSECRET']._serialized_start=1409
  _globals['_LOCKBOXSECRET']._serialized_end=1477
  _globals['_CONNECTION']._serialized_start=1480
  _globals['_CONNECTION']._serialized_end=2022
  _globals['_CONNECTION_LABELSENTRY']._serialized_start=1961
  _globals['_CONNECTION_LABELSENTRY']._serialized_end=2006
# @@protoc_insertion_point(module_scope)
